@@ -14,14 +14,22 @@ func NewTestifylint(settings *config.TestifylintSettings) *goanalysis.Linter {
 	cfg := make(map[string]map[string]any)
 	if settings != nil {
 		cfg[a.Name] = map[string]any{
-			"enable-all": settings.EnableAll,
+			"enable-all":  settings.EnableAll,
+			"disable-all": settings.DisableAll,
 		}
 		if len(settings.EnabledCheckers) > 0 {
 			cfg[a.Name]["enable"] = settings.EnabledCheckers
 		}
+		if len(settings.DisabledCheckers) > 0 {
+			cfg[a.Name]["disable"] = settings.DisabledCheckers
+		}
+
 		if p := settings.ExpectedActual.ExpVarPattern; p != "" {
 			cfg[a.Name]["expected-actual.pattern"] = p
 		}
+		if p := settings.RequireError.FnPattern; p != "" {
+			cfg[a.Name]["require-error.fn-pattern"] = p
+		}
 		if m := settings.SuiteExtraAssertCall.Mode; m != "" {
 			cfg[a.Name]["suite-extra-assert-call.mode"] = m
 		}
